// Copyright 1986-2022 Xilinx, Inc. All Rights Reserved.
// --------------------------------------------------------------------------------
// Tool Version: Vivado v.2022.1 (lin64) Build 3526262 Mon Apr 18 15:47:01 MDT 2022
// Date        : Mon May 13 11:35:59 2024
// Host        : atlas-tdaq-firmware-dev.cern.ch running 64-bit CentOS Linux release 7.9.2009 (Core)
// Command     : write_verilog -force -mode synth_stub
//               /home/gitlab-runner/builds/z7w3GeU4/0/atlas-l1calo-efex/RODFirmware/IP/bkpln_efex/aurora_rx_4l_64b/aurora_rx_4l_64b_stub.v
// Design      : aurora_rx_4l_64b
// Purpose     : Stub declaration of top-level module interface
// Device      : xc7vx550tffg1927-2
// --------------------------------------------------------------------------------

// This empty module with port declaration file causes synthesis tools to infer a black box for IP.
// The synthesis directives are for Synopsys Synplify support to prevent IO buffer insertion.
// Please paste the declaration into a Verilog source file or add the file as an additional source.
module aurora_rx_4l_64b(m_axi_rx_tdata, m_axi_rx_tvalid, 
  m_axi_rx_tkeep, m_axi_rx_tlast, m_axi_ufc_rx_tdata, m_axi_ufc_rx_tkeep, 
  m_axi_ufc_rx_tvalid, m_axi_ufc_rx_tlast, rxp, rxn, gt_refclk1, frame_err, rx_hard_err, 
  soft_err, rx_lane_up, rx_channel_up, user_clk, sync_clk, rx_system_reset, power_down, loopback, 
  gt_reset, tx_lock, sys_reset_out, init_clk_in, rx_resetdone_out, link_reset_out, drpclk_in, 
  drpaddr_in, drpdi_in, drpdo_out, drpen_in, drprdy_out, drpwe_in, drpaddr_in_lane1, 
  drpdi_in_lane1, drpdo_out_lane1, drpen_in_lane1, drprdy_out_lane1, drpwe_in_lane1, 
  drpaddr_in_lane2, drpdi_in_lane2, drpdo_out_lane2, drpen_in_lane2, drprdy_out_lane2, 
  drpwe_in_lane2, drpaddr_in_lane3, drpdi_in_lane3, drpdo_out_lane3, drpen_in_lane3, 
  drprdy_out_lane3, drpwe_in_lane3, gt0_cplllock_out, gt0_rxlpmen_in, gt0_rxcdrovrden_in, 
  gt0_rxdfelpmreset_in, gt0_rxmonitorout_out, gt0_rxmonitorsel_in, gt0_rxcdrhold_in, 
  gt0_eyescanreset_in, gt0_eyescandataerror_out, gt0_eyescantrigger_in, 
  gt0_rxbyteisaligned_out, gt0_rxcommadet_out, gt0_rxprbserr_out, gt0_rxprbssel_in, 
  gt0_rxprbscntreset_in, gt0_rxpcsreset_in, gt0_rxpmareset_in, gt0_rxpmaresetdone_out, 
  gt0_dmonitorout_out, gt0_rxbufreset_in, gt0_rx_disp_err_out, gt0_rx_not_in_table_out, 
  gt0_rx_realign_out, gt0_rx_buf_err_out, gt0_rxresetdone_out, gt0_rxbufstatus_out, 
  gt1_cplllock_out, gt1_rxlpmen_in, gt1_rxcdrovrden_in, gt1_rxdfelpmreset_in, 
  gt1_rxmonitorout_out, gt1_rxmonitorsel_in, gt1_rxcdrhold_in, gt1_eyescanreset_in, 
  gt1_eyescandataerror_out, gt1_eyescantrigger_in, gt1_rxbyteisaligned_out, 
  gt1_rxcommadet_out, gt1_rxprbserr_out, gt1_rxprbssel_in, gt1_rxprbscntreset_in, 
  gt1_rxpcsreset_in, gt1_rxpmareset_in, gt1_rxpmaresetdone_out, gt1_dmonitorout_out, 
  gt1_rxbufreset_in, gt1_rx_disp_err_out, gt1_rx_not_in_table_out, gt1_rx_realign_out, 
  gt1_rx_buf_err_out, gt1_rxresetdone_out, gt1_rxbufstatus_out, gt2_cplllock_out, 
  gt2_rxlpmen_in, gt2_rxcdrovrden_in, gt2_rxdfelpmreset_in, gt2_rxmonitorout_out, 
  gt2_rxmonitorsel_in, gt2_rxcdrhold_in, gt2_eyescanreset_in, gt2_eyescandataerror_out, 
  gt2_eyescantrigger_in, gt2_rxbyteisaligned_out, gt2_rxcommadet_out, gt2_rxprbserr_out, 
  gt2_rxprbssel_in, gt2_rxprbscntreset_in, gt2_rxpcsreset_in, gt2_rxpmareset_in, 
  gt2_rxpmaresetdone_out, gt2_dmonitorout_out, gt2_rxbufreset_in, gt2_rx_disp_err_out, 
  gt2_rx_not_in_table_out, gt2_rx_realign_out, gt2_rx_buf_err_out, gt2_rxresetdone_out, 
  gt2_rxbufstatus_out, gt3_cplllock_out, gt3_rxlpmen_in, gt3_rxcdrovrden_in, 
  gt3_rxdfelpmreset_in, gt3_rxmonitorout_out, gt3_rxmonitorsel_in, gt3_rxcdrhold_in, 
  gt3_eyescanreset_in, gt3_eyescandataerror_out, gt3_eyescantrigger_in, 
  gt3_rxbyteisaligned_out, gt3_rxcommadet_out, gt3_rxprbserr_out, gt3_rxprbssel_in, 
  gt3_rxprbscntreset_in, gt3_rxpcsreset_in, gt3_rxpmareset_in, gt3_rxpmaresetdone_out, 
  gt3_dmonitorout_out, gt3_rxbufreset_in, gt3_rx_disp_err_out, gt3_rx_not_in_table_out, 
  gt3_rx_realign_out, gt3_rx_buf_err_out, gt3_rxresetdone_out, gt3_rxbufstatus_out, 
  gt0_qplllock_in, gt0_qpllrefclklost_in, gt0_qpllreset_out, gt1_qplllock_in, 
  gt1_qpllrefclklost_in, gt1_qpllreset_out, gt_qpllclk_quad2_in, gt_qpllrefclk_quad2_in, 
  gt_qpllclk_quad3_in, gt_qpllrefclk_quad3_in, tx_out_clk, pll_not_locked)
/* synthesis syn_black_box black_box_pad_pin="m_axi_rx_tdata[63:0],m_axi_rx_tvalid,m_axi_rx_tkeep[7:0],m_axi_rx_tlast,m_axi_ufc_rx_tdata[63:0],m_axi_ufc_rx_tkeep[7:0],m_axi_ufc_rx_tvalid,m_axi_ufc_rx_tlast,rxp[0:3],rxn[0:3],gt_refclk1,frame_err,rx_hard_err,soft_err,rx_lane_up[0:3],rx_channel_up,user_clk,sync_clk,rx_system_reset,power_down,loopback[2:0],gt_reset,tx_lock,sys_reset_out,init_clk_in,rx_resetdone_out,link_reset_out,drpclk_in,drpaddr_in[8:0],drpdi_in[15:0],drpdo_out[15:0],drpen_in,drprdy_out,drpwe_in,drpaddr_in_lane1[8:0],drpdi_in_lane1[15:0],drpdo_out_lane1[15:0],drpen_in_lane1,drprdy_out_lane1,drpwe_in_lane1,drpaddr_in_lane2[8:0],drpdi_in_lane2[15:0],drpdo_out_lane2[15:0],drpen_in_lane2,drprdy_out_lane2,drpwe_in_lane2,drpaddr_in_lane3[8:0],drpdi_in_lane3[15:0],drpdo_out_lane3[15:0],drpen_in_lane3,drprdy_out_lane3,drpwe_in_lane3,gt0_cplllock_out,gt0_rxlpmen_in,gt0_rxcdrovrden_in,gt0_rxdfelpmreset_in,gt0_rxmonitorout_out[6:0],gt0_rxmonitorsel_in[1:0],gt0_rxcdrhold_in,gt0_eyescanreset_in,gt0_eyescandataerror_out,gt0_eyescantrigger_in,gt0_rxbyteisaligned_out,gt0_rxcommadet_out,gt0_rxprbserr_out,gt0_rxprbssel_in[2:0],gt0_rxprbscntreset_in,gt0_rxpcsreset_in,gt0_rxpmareset_in,gt0_rxpmaresetdone_out,gt0_dmonitorout_out[14:0],gt0_rxbufreset_in,gt0_rx_disp_err_out[1:0],gt0_rx_not_in_table_out[1:0],gt0_rx_realign_out,gt0_rx_buf_err_out,gt0_rxresetdone_out,gt0_rxbufstatus_out[2:0],gt1_cplllock_out,gt1_rxlpmen_in,gt1_rxcdrovrden_in,gt1_rxdfelpmreset_in,gt1_rxmonitorout_out[6:0],gt1_rxmonitorsel_in[1:0],gt1_rxcdrhold_in,gt1_eyescanreset_in,gt1_eyescandataerror_out,gt1_eyescantrigger_in,gt1_rxbyteisaligned_out,gt1_rxcommadet_out,gt1_rxprbserr_out,gt1_rxprbssel_in[2:0],gt1_rxprbscntreset_in,gt1_rxpcsreset_in,gt1_rxpmareset_in,gt1_rxpmaresetdone_out,gt1_dmonitorout_out[14:0],gt1_rxbufreset_in,gt1_rx_disp_err_out[1:0],gt1_rx_not_in_table_out[1:0],gt1_rx_realign_out,gt1_rx_buf_err_out,gt1_rxresetdone_out,gt1_rxbufstatus_out[2:0],gt2_cplllock_out,gt2_rxlpmen_in,gt2_rxcdrovrden_in,gt2_rxdfelpmreset_in,gt2_rxmonitorout_out[6:0],gt2_rxmonitorsel_in[1:0],gt2_rxcdrhold_in,gt2_eyescanreset_in,gt2_eyescandataerror_out,gt2_eyescantrigger_in,gt2_rxbyteisaligned_out,gt2_rxcommadet_out,gt2_rxprbserr_out,gt2_rxprbssel_in[2:0],gt2_rxprbscntreset_in,gt2_rxpcsreset_in,gt2_rxpmareset_in,gt2_rxpmaresetdone_out,gt2_dmonitorout_out[14:0],gt2_rxbufreset_in,gt2_rx_disp_err_out[1:0],gt2_rx_not_in_table_out[1:0],gt2_rx_realign_out,gt2_rx_buf_err_out,gt2_rxresetdone_out,gt2_rxbufstatus_out[2:0],gt3_cplllock_out,gt3_rxlpmen_in,gt3_rxcdrovrden_in,gt3_rxdfelpmreset_in,gt3_rxmonitorout_out[6:0],gt3_rxmonitorsel_in[1:0],gt3_rxcdrhold_in,gt3_eyescanreset_in,gt3_eyescandataerror_out,gt3_eyescantrigger_in,gt3_rxbyteisaligned_out,gt3_rxcommadet_out,gt3_rxprbserr_out,gt3_rxprbssel_in[2:0],gt3_rxprbscntreset_in,gt3_rxpcsreset_in,gt3_rxpmareset_in,gt3_rxpmaresetdone_out,gt3_dmonitorout_out[14:0],gt3_rxbufreset_in,gt3_rx_disp_err_out[1:0],gt3_rx_not_in_table_out[1:0],gt3_rx_realign_out,gt3_rx_buf_err_out,gt3_rxresetdone_out,gt3_rxbufstatus_out[2:0],gt0_qplllock_in,gt0_qpllrefclklost_in,gt0_qpllreset_out,gt1_qplllock_in,gt1_qpllrefclklost_in,gt1_qpllreset_out,gt_qpllclk_quad2_in,gt_qpllrefclk_quad2_in,gt_qpllclk_quad3_in,gt_qpllrefclk_quad3_in,tx_out_clk,pll_not_locked" */;
  output [63:0]m_axi_rx_tdata;
  output m_axi_rx_tvalid;
  output [7:0]m_axi_rx_tkeep;
  output m_axi_rx_tlast;
  output [63:0]m_axi_ufc_rx_tdata;
  output [7:0]m_axi_ufc_rx_tkeep;
  output m_axi_ufc_rx_tvalid;
  output m_axi_ufc_rx_tlast;
  input [0:3]rxp;
  input [0:3]rxn;
  input gt_refclk1;
  output frame_err;
  output rx_hard_err;
  output soft_err;
  output [0:3]rx_lane_up;
  output rx_channel_up;
  input user_clk;
  input sync_clk;
  input rx_system_reset;
  input power_down;
  input [2:0]loopback;
  input gt_reset;
  output tx_lock;
  output sys_reset_out;
  input init_clk_in;
  output rx_resetdone_out;
  output link_reset_out;
  input drpclk_in;
  input [8:0]drpaddr_in;
  input [15:0]drpdi_in;
  output [15:0]drpdo_out;
  input drpen_in;
  output drprdy_out;
  input drpwe_in;
  input [8:0]drpaddr_in_lane1;
  input [15:0]drpdi_in_lane1;
  output [15:0]drpdo_out_lane1;
  input drpen_in_lane1;
  output drprdy_out_lane1;
  input drpwe_in_lane1;
  input [8:0]drpaddr_in_lane2;
  input [15:0]drpdi_in_lane2;
  output [15:0]drpdo_out_lane2;
  input drpen_in_lane2;
  output drprdy_out_lane2;
  input drpwe_in_lane2;
  input [8:0]drpaddr_in_lane3;
  input [15:0]drpdi_in_lane3;
  output [15:0]drpdo_out_lane3;
  input drpen_in_lane3;
  output drprdy_out_lane3;
  input drpwe_in_lane3;
  output gt0_cplllock_out;
  input gt0_rxlpmen_in;
  input gt0_rxcdrovrden_in;
  input gt0_rxdfelpmreset_in;
  output [6:0]gt0_rxmonitorout_out;
  input [1:0]gt0_rxmonitorsel_in;
  input gt0_rxcdrhold_in;
  input gt0_eyescanreset_in;
  output gt0_eyescandataerror_out;
  input gt0_eyescantrigger_in;
  output gt0_rxbyteisaligned_out;
  output gt0_rxcommadet_out;
  output gt0_rxprbserr_out;
  input [2:0]gt0_rxprbssel_in;
  input gt0_rxprbscntreset_in;
  input gt0_rxpcsreset_in;
  input gt0_rxpmareset_in;
  output gt0_rxpmaresetdone_out;
  output [14:0]gt0_dmonitorout_out;
  input gt0_rxbufreset_in;
  output [1:0]gt0_rx_disp_err_out;
  output [1:0]gt0_rx_not_in_table_out;
  output gt0_rx_realign_out;
  output gt0_rx_buf_err_out;
  output gt0_rxresetdone_out;
  output [2:0]gt0_rxbufstatus_out;
  output gt1_cplllock_out;
  input gt1_rxlpmen_in;
  input gt1_rxcdrovrden_in;
  input gt1_rxdfelpmreset_in;
  output [6:0]gt1_rxmonitorout_out;
  input [1:0]gt1_rxmonitorsel_in;
  input gt1_rxcdrhold_in;
  input gt1_eyescanreset_in;
  output gt1_eyescandataerror_out;
  input gt1_eyescantrigger_in;
  output gt1_rxbyteisaligned_out;
  output gt1_rxcommadet_out;
  output gt1_rxprbserr_out;
  input [2:0]gt1_rxprbssel_in;
  input gt1_rxprbscntreset_in;
  input gt1_rxpcsreset_in;
  input gt1_rxpmareset_in;
  output gt1_rxpmaresetdone_out;
  output [14:0]gt1_dmonitorout_out;
  input gt1_rxbufreset_in;
  output [1:0]gt1_rx_disp_err_out;
  output [1:0]gt1_rx_not_in_table_out;
  output gt1_rx_realign_out;
  output gt1_rx_buf_err_out;
  output gt1_rxresetdone_out;
  output [2:0]gt1_rxbufstatus_out;
  output gt2_cplllock_out;
  input gt2_rxlpmen_in;
  input gt2_rxcdrovrden_in;
  input gt2_rxdfelpmreset_in;
  output [6:0]gt2_rxmonitorout_out;
  input [1:0]gt2_rxmonitorsel_in;
  input gt2_rxcdrhold_in;
  input gt2_eyescanreset_in;
  output gt2_eyescandataerror_out;
  input gt2_eyescantrigger_in;
  output gt2_rxbyteisaligned_out;
  output gt2_rxcommadet_out;
  output gt2_rxprbserr_out;
  input [2:0]gt2_rxprbssel_in;
  input gt2_rxprbscntreset_in;
  input gt2_rxpcsreset_in;
  input gt2_rxpmareset_in;
  output gt2_rxpmaresetdone_out;
  output [14:0]gt2_dmonitorout_out;
  input gt2_rxbufreset_in;
  output [1:0]gt2_rx_disp_err_out;
  output [1:0]gt2_rx_not_in_table_out;
  output gt2_rx_realign_out;
  output gt2_rx_buf_err_out;
  output gt2_rxresetdone_out;
  output [2:0]gt2_rxbufstatus_out;
  output gt3_cplllock_out;
  input gt3_rxlpmen_in;
  input gt3_rxcdrovrden_in;
  input gt3_rxdfelpmreset_in;
  output [6:0]gt3_rxmonitorout_out;
  input [1:0]gt3_rxmonitorsel_in;
  input gt3_rxcdrhold_in;
  input gt3_eyescanreset_in;
  output gt3_eyescandataerror_out;
  input gt3_eyescantrigger_in;
  output gt3_rxbyteisaligned_out;
  output gt3_rxcommadet_out;
  output gt3_rxprbserr_out;
  input [2:0]gt3_rxprbssel_in;
  input gt3_rxprbscntreset_in;
  input gt3_rxpcsreset_in;
  input gt3_rxpmareset_in;
  output gt3_rxpmaresetdone_out;
  output [14:0]gt3_dmonitorout_out;
  input gt3_rxbufreset_in;
  output [1:0]gt3_rx_disp_err_out;
  output [1:0]gt3_rx_not_in_table_out;
  output gt3_rx_realign_out;
  output gt3_rx_buf_err_out;
  output gt3_rxresetdone_out;
  output [2:0]gt3_rxbufstatus_out;
  input gt0_qplllock_in;
  input gt0_qpllrefclklost_in;
  output gt0_qpllreset_out;
  input gt1_qplllock_in;
  input gt1_qpllrefclklost_in;
  output gt1_qpllreset_out;
  input gt_qpllclk_quad2_in;
  input gt_qpllrefclk_quad2_in;
  input gt_qpllclk_quad3_in;
  input gt_qpllrefclk_quad3_in;
  output tx_out_clk;
  input pll_not_locked;
endmodule
