-- (c) Copyright 2008 Xilinx, Inc. All rights reserved.
--
-- This file contains confidential and proprietary information
-- of Xilinx, Inc. and is protected under U.S. and
-- international copyright and other intellectual property
-- laws.
--
-- DISCLAIMER
-- This disclaimer is not a license and does not grant any
-- rights to the materials distributed herewith. Except as
-- otherwise provided in a valid license issued to you by
-- Xilinx, and to the maximum extent permitted by applicable
-- law: (1) THESE MATERIALS ARE MADE AVAILABLE "AS IS" AND
-- WITH ALL FAULTS, AND XILINX HEREBY DISCLAIMS ALL WARRANTIES
-- AND CONDITIONS, EXPRESS, IMPLIED, OR STATUTORY, INCLUDING
-- BUT NOT LIMITED TO WARRANTIES OF MERCHANTABILITY, NON-
-- INFRINGEMENT, OR FITNESS FOR ANY PARTICULAR PURPOSE; and
-- (2) Xilinx shall not be liable (whether in contract or tort,
-- including negligence, or under any other theory of
-- liability) for any loss or damage of any kind or nature
-- related to, arising under or in connection with these
-- materials, including for any direct, or any indirect,
-- special, incidental, or consequential loss or damage
-- (including loss of data, profits, goodwill, or any type of
-- loss or damage suffered as a result of any action brought
-- by a third party) even if such damage or loss was
-- reasonably foreseeable or Xilinx had been advised of the
-- possibility of the same.
--
-- CRITICAL APPLICATIONS
-- Xilinx products are not designed or intended to be fail-
-- safe, or for use in any application requiring fail-safe
-- performance, such as life-support or safety devices or
-- systems, Class III medical devices, nuclear facilities,
-- applications related to the deployment of airbags, or any
-- other applications that could lead to death, personal
-- injury, or severe property or environmental damage
-- (individually and collectively, "Critical
-- Applications"). Customer assumes the sole risk and
-- liability of any use of Xilinx products in Critical
-- Applications, subject only to applicable laws and
-- regulations governing limitations on product liability.
--
-- THIS COPYRIGHT NOTICE AND DISCLAIMER MUST BE RETAINED AS
-- PART OF THIS FILE AT ALL TIMES.
--
--

--
--  RX_LL
--
--
--
--  Description: The RX_LL module receives data from the Aurora Channel,
--               converts it to LocalLink and sends it to the user interface.
--               It also handles NFC and UFC messages.
--
--               This module supports 4 2-byte lane designs.
--
--               This module supports User Flow Control.
--

library IEEE;
use IEEE.STD_LOGIC_1164.all;

entity aurora_rx_4l_64b_RX_LL is

    port (

    -- LocalLink PDU Interface

RX_D             : out std_logic_vector(0 to 63);
RX_REM           : out std_logic_vector(0 to 2);
            RX_SRC_RDY_N     : out std_logic;
            RX_SOF_N         : out std_logic;
            RX_EOF_N         : out std_logic;

    -- UFC Interface

UFC_RX_DATA      : out std_logic_vector(0 to 63);
UFC_RX_REM       : out std_logic_vector(0 to 2);
            UFC_RX_SRC_RDY_N : out std_logic;
            UFC_RX_SOF_N     : out std_logic;
            UFC_RX_EOF_N     : out std_logic;

    -- Global Logic Interface

            START_RX         : in std_logic;

    -- Aurora Lane Interface

RX_PAD           : in std_logic_vector(0 to 3);
RX_PE_DATA       : in std_logic_vector(0 to 63);
RX_PE_DATA_V     : in std_logic_vector(0 to 3);
RX_SCP           : in std_logic_vector(0 to 3);
RX_ECP           : in std_logic_vector(0 to 3);
RX_SUF           : in std_logic_vector(0 to 3);
RX_FC_NB         : in std_logic_vector(0 to 15);

    -- Error Interface

            FRAME_ERR      : out std_logic;

    -- System Interface

            USER_CLK         : in std_logic

         );

end aurora_rx_4l_64b_RX_LL;

architecture MAPPED of aurora_rx_4l_64b_RX_LL is

-- External Register Declarations --

signal RX_D_Buffer             : std_logic_vector(0 to 63);
signal RX_REM_Buffer           : std_logic_vector(0 to 2);
    signal RX_SRC_RDY_N_Buffer     : std_logic;
    signal RX_SOF_N_Buffer         : std_logic;
    signal RX_EOF_N_Buffer         : std_logic;
signal UFC_RX_DATA_Buffer      : std_logic_vector(0 to 63);
signal UFC_RX_REM_Buffer       : std_logic_vector(0 to 2);
    signal UFC_RX_SRC_RDY_N_Buffer : std_logic;
    signal UFC_RX_SOF_N_Buffer     : std_logic;
    signal UFC_RX_EOF_N_Buffer     : std_logic;
    signal FRAME_ERR_Buffer      : std_logic;

-- Wire Declarations --

signal pdu_pad_i           : std_logic_vector(0 to 3);
signal pdu_data_i          : std_logic_vector(0 to 63);
signal pdu_data_v_i        : std_logic_vector(0 to 3);
signal pdu_scp_i           : std_logic_vector(0 to 3);
signal pdu_ecp_i           : std_logic_vector(0 to 3);
signal ufc_message_start_i : std_logic_vector(0 to 3);
signal ufc_data_i          : std_logic_vector(0 to 63);
signal ufc_data_v_i        : std_logic_vector(0 to 3);
    signal ufc_start_i         : std_logic;

    signal start_rx_i          : std_logic;

-- Component Declarations --

    component aurora_rx_4l_64b_UFC_FILTER

        port (

        -- Aurora Channel Interface

RX_PAD            : in std_logic_vector(0 to 3);
RX_PE_DATA        : in std_logic_vector(0 to 63);
RX_PE_DATA_V      : in std_logic_vector(0 to 3);
RX_SCP            : in std_logic_vector(0 to 3);
RX_ECP            : in std_logic_vector(0 to 3);
RX_SUF            : in std_logic_vector(0 to 3);
RX_FC_NB          : in std_logic_vector(0 to 15);

        -- PDU Datapath Interface

PDU_DATA          : out std_logic_vector(0 to 63);
PDU_DATA_V        : out std_logic_vector(0 to 3);
PDU_PAD           : out std_logic_vector(0 to 3);
PDU_SCP           : out std_logic_vector(0 to 3);
PDU_ECP           : out std_logic_vector(0 to 3);

        -- UFC Datapath Interface

UFC_DATA          : out std_logic_vector(0 to 63);
UFC_DATA_V        : out std_logic_vector(0 to 3);
UFC_MESSAGE_START : out std_logic_vector(0 to 3);
                UFC_START         : out std_logic;

        -- System Interface

                USER_CLK          : in std_logic;
                RESET             : in std_logic

             );

    end component;


    component aurora_rx_4l_64b_RX_LL_PDU_DATAPATH

        port (

        -- Traffic Separator Interface

PDU_DATA     : in std_logic_vector(0 to 63);
PDU_DATA_V   : in std_logic_vector(0 to 3);
PDU_PAD      : in std_logic_vector(0 to 3);
PDU_SCP      : in std_logic_vector(0 to 3);
PDU_ECP      : in std_logic_vector(0 to 3);

        -- LocalLink PDU Interface

RX_D         : out std_logic_vector(0 to 63);
RX_REM       : out std_logic_vector(0 to 2);
                RX_SRC_RDY_N : out std_logic;
                RX_SOF_N     : out std_logic;
                RX_EOF_N     : out std_logic;

        -- Error Interface

                FRAME_ERR  : out std_logic;

        -- System Interface

                USER_CLK     : in std_logic;
                RESET        : in std_logic

             );

    end component;


    component aurora_rx_4l_64b_RX_LL_UFC_DATAPATH

        port (

        --Traffic Separator Interface

UFC_DATA          : in std_logic_vector(0 to 63);
UFC_DATA_V        : in std_logic_vector(0 to 3);
UFC_MESSAGE_START : in std_logic_vector(0 to 3);
                UFC_START         : in std_logic;

        --LocalLink UFC Interface

UFC_RX_DATA       : out std_logic_vector(0 to 63);
UFC_RX_REM        : out std_logic_vector(0 to 2);
                UFC_RX_SRC_RDY_N  : out std_logic;
                UFC_RX_SOF_N      : out std_logic;
                UFC_RX_EOF_N      : out std_logic;

        --System Interface

                USER_CLK          : in std_logic;
                RESET             : in std_logic

             );

    end component;


begin

    RX_D             <= RX_D_Buffer;
    RX_REM           <= RX_REM_Buffer;
    RX_SRC_RDY_N     <= RX_SRC_RDY_N_Buffer;
    RX_SOF_N         <= RX_SOF_N_Buffer;
    RX_EOF_N         <= RX_EOF_N_Buffer;
    UFC_RX_DATA      <= UFC_RX_DATA_Buffer;
    UFC_RX_REM       <= UFC_RX_REM_Buffer;
    UFC_RX_SRC_RDY_N <= UFC_RX_SRC_RDY_N_Buffer;
    UFC_RX_SOF_N     <= UFC_RX_SOF_N_Buffer;
    UFC_RX_EOF_N     <= UFC_RX_EOF_N_Buffer;
    FRAME_ERR      <= FRAME_ERR_Buffer;

    start_rx_i       <= not START_RX;

-- Main Body of Code --

    -- Separate UFC traffic from regular data --

    ufc_filter_i : aurora_rx_4l_64b_UFC_FILTER

        port map (

        -- Aurora Channel Interface

                    RX_PAD            => RX_PAD,
                    RX_PE_DATA        => RX_PE_DATA,
                    RX_PE_DATA_V      => RX_PE_DATA_V,
                    RX_SCP            => RX_SCP,
                    RX_ECP            => RX_ECP,
                    RX_SUF            => RX_SUF,
                    RX_FC_NB          => RX_FC_NB,

        -- PDU Datapath Interface

                    PDU_DATA          => pdu_data_i,
                    PDU_DATA_V        => pdu_data_v_i,
                    PDU_PAD           => pdu_pad_i,
                    PDU_SCP           => pdu_scp_i,
                    PDU_ECP           => pdu_ecp_i,

        -- UFC Datapath Interface

                    UFC_DATA          => ufc_data_i,
                    UFC_DATA_V        => ufc_data_v_i,
                    UFC_MESSAGE_START => ufc_message_start_i,
                    UFC_START         => ufc_start_i,

        -- System Interface

                    USER_CLK          => USER_CLK,
                    RESET             => start_rx_i

                 );


    -- Datapath for user PDUs --

    rx_ll_pdu_datapath_i : aurora_rx_4l_64b_RX_LL_PDU_DATAPATH

        port map (

        -- Traffic Separator Interface

                    PDU_DATA     => pdu_data_i,
                    PDU_DATA_V   => pdu_data_v_i,
                    PDU_PAD      => pdu_pad_i,
                    PDU_SCP      => pdu_scp_i,
                    PDU_ECP      => pdu_ecp_i,

        -- LocalLink PDU Interface

                    RX_D         => RX_D_Buffer,
                    RX_REM       => RX_REM_Buffer,
                    RX_SRC_RDY_N => RX_SRC_RDY_N_Buffer,
                    RX_SOF_N     => RX_SOF_N_Buffer,
                    RX_EOF_N     => RX_EOF_N_Buffer,

        -- Error Interface

                    FRAME_ERR  => FRAME_ERR_Buffer,

        -- System Interface

                    USER_CLK     => USER_CLK,
                    RESET        => start_rx_i

                 );


    -- Datapath for UFC PDUs --

    rx_ll_ufc_datapath_i : aurora_rx_4l_64b_RX_LL_UFC_DATAPATH

        port map (

        -- Traffic Separator Interface

                    UFC_DATA          => ufc_data_i,
                    UFC_DATA_V        => ufc_data_v_i,
                    UFC_MESSAGE_START => ufc_message_start_i,
                    UFC_START         => ufc_start_i,

        -- LocalLink PDU Interface

                    UFC_RX_DATA       => UFC_RX_DATA_Buffer,
                    UFC_RX_REM        => UFC_RX_REM_Buffer,
                    UFC_RX_SRC_RDY_N  => UFC_RX_SRC_RDY_N_Buffer,
                    UFC_RX_SOF_N      => UFC_RX_SOF_N_Buffer,
                    UFC_RX_EOF_N      => UFC_RX_EOF_N_Buffer,

        -- System Interface

                    USER_CLK          => USER_CLK,
                    RESET             => start_rx_i

                 );


end MAPPED;
