-- Copyright 1986-2022 Xilinx, Inc. All Rights Reserved.
-- --------------------------------------------------------------------------------
-- Tool Version: Vivado v.2022.1 (lin64) Build 3526262 Mon Apr 18 15:47:01 MDT 2022
-- Date        : Mon May 13 11:35:59 2024
-- Host        : atlas-tdaq-firmware-dev.cern.ch running 64-bit CentOS Linux release 7.9.2009 (Core)
-- Command     : write_vhdl -force -mode synth_stub
--               /home/gitlab-runner/builds/z7w3GeU4/0/atlas-l1calo-efex/RODFirmware/IP/bkpln_efex/aurora_rx_4l_64b/aurora_rx_4l_64b_stub.vhdl
-- Design      : aurora_rx_4l_64b
-- Purpose     : Stub declaration of top-level module interface
-- Device      : xc7vx550tffg1927-2
-- --------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

entity aurora_rx_4l_64b is
  Port ( 
    m_axi_rx_tdata : out STD_LOGIC_VECTOR ( 63 downto 0 );
    m_axi_rx_tvalid : out STD_LOGIC;
    m_axi_rx_tkeep : out STD_LOGIC_VECTOR ( 7 downto 0 );
    m_axi_rx_tlast : out STD_LOGIC;
    m_axi_ufc_rx_tdata : out STD_LOGIC_VECTOR ( 63 downto 0 );
    m_axi_ufc_rx_tkeep : out STD_LOGIC_VECTOR ( 7 downto 0 );
    m_axi_ufc_rx_tvalid : out STD_LOGIC;
    m_axi_ufc_rx_tlast : out STD_LOGIC;
    rxp : in STD_LOGIC_VECTOR ( 0 to 3 );
    rxn : in STD_LOGIC_VECTOR ( 0 to 3 );
    gt_refclk1 : in STD_LOGIC;
    frame_err : out STD_LOGIC;
    rx_hard_err : out STD_LOGIC;
    soft_err : out STD_LOGIC;
    rx_lane_up : out STD_LOGIC_VECTOR ( 0 to 3 );
    rx_channel_up : out STD_LOGIC;
    user_clk : in STD_LOGIC;
    sync_clk : in STD_LOGIC;
    rx_system_reset : in STD_LOGIC;
    power_down : in STD_LOGIC;
    loopback : in STD_LOGIC_VECTOR ( 2 downto 0 );
    gt_reset : in STD_LOGIC;
    tx_lock : out STD_LOGIC;
    sys_reset_out : out STD_LOGIC;
    init_clk_in : in STD_LOGIC;
    rx_resetdone_out : out STD_LOGIC;
    link_reset_out : out STD_LOGIC;
    drpclk_in : in STD_LOGIC;
    drpaddr_in : in STD_LOGIC_VECTOR ( 8 downto 0 );
    drpdi_in : in STD_LOGIC_VECTOR ( 15 downto 0 );
    drpdo_out : out STD_LOGIC_VECTOR ( 15 downto 0 );
    drpen_in : in STD_LOGIC;
    drprdy_out : out STD_LOGIC;
    drpwe_in : in STD_LOGIC;
    drpaddr_in_lane1 : in STD_LOGIC_VECTOR ( 8 downto 0 );
    drpdi_in_lane1 : in STD_LOGIC_VECTOR ( 15 downto 0 );
    drpdo_out_lane1 : out STD_LOGIC_VECTOR ( 15 downto 0 );
    drpen_in_lane1 : in STD_LOGIC;
    drprdy_out_lane1 : out STD_LOGIC;
    drpwe_in_lane1 : in STD_LOGIC;
    drpaddr_in_lane2 : in STD_LOGIC_VECTOR ( 8 downto 0 );
    drpdi_in_lane2 : in STD_LOGIC_VECTOR ( 15 downto 0 );
    drpdo_out_lane2 : out STD_LOGIC_VECTOR ( 15 downto 0 );
    drpen_in_lane2 : in STD_LOGIC;
    drprdy_out_lane2 : out STD_LOGIC;
    drpwe_in_lane2 : in STD_LOGIC;
    drpaddr_in_lane3 : in STD_LOGIC_VECTOR ( 8 downto 0 );
    drpdi_in_lane3 : in STD_LOGIC_VECTOR ( 15 downto 0 );
    drpdo_out_lane3 : out STD_LOGIC_VECTOR ( 15 downto 0 );
    drpen_in_lane3 : in STD_LOGIC;
    drprdy_out_lane3 : out STD_LOGIC;
    drpwe_in_lane3 : in STD_LOGIC;
    gt0_cplllock_out : out STD_LOGIC;
    gt0_rxlpmen_in : in STD_LOGIC;
    gt0_rxcdrovrden_in : in STD_LOGIC;
    gt0_rxdfelpmreset_in : in STD_LOGIC;
    gt0_rxmonitorout_out : out STD_LOGIC_VECTOR ( 6 downto 0 );
    gt0_rxmonitorsel_in : in STD_LOGIC_VECTOR ( 1 downto 0 );
    gt0_rxcdrhold_in : in STD_LOGIC;
    gt0_eyescanreset_in : in STD_LOGIC;
    gt0_eyescandataerror_out : out STD_LOGIC;
    gt0_eyescantrigger_in : in STD_LOGIC;
    gt0_rxbyteisaligned_out : out STD_LOGIC;
    gt0_rxcommadet_out : out STD_LOGIC;
    gt0_rxprbserr_out : out STD_LOGIC;
    gt0_rxprbssel_in : in STD_LOGIC_VECTOR ( 2 downto 0 );
    gt0_rxprbscntreset_in : in STD_LOGIC;
    gt0_rxpcsreset_in : in STD_LOGIC;
    gt0_rxpmareset_in : in STD_LOGIC;
    gt0_rxpmaresetdone_out : out STD_LOGIC;
    gt0_dmonitorout_out : out STD_LOGIC_VECTOR ( 14 downto 0 );
    gt0_rxbufreset_in : in STD_LOGIC;
    gt0_rx_disp_err_out : out STD_LOGIC_VECTOR ( 1 downto 0 );
    gt0_rx_not_in_table_out : out STD_LOGIC_VECTOR ( 1 downto 0 );
    gt0_rx_realign_out : out STD_LOGIC;
    gt0_rx_buf_err_out : out STD_LOGIC;
    gt0_rxresetdone_out : out STD_LOGIC;
    gt0_rxbufstatus_out : out STD_LOGIC_VECTOR ( 2 downto 0 );
    gt1_cplllock_out : out STD_LOGIC;
    gt1_rxlpmen_in : in STD_LOGIC;
    gt1_rxcdrovrden_in : in STD_LOGIC;
    gt1_rxdfelpmreset_in : in STD_LOGIC;
    gt1_rxmonitorout_out : out STD_LOGIC_VECTOR ( 6 downto 0 );
    gt1_rxmonitorsel_in : in STD_LOGIC_VECTOR ( 1 downto 0 );
    gt1_rxcdrhold_in : in STD_LOGIC;
    gt1_eyescanreset_in : in STD_LOGIC;
    gt1_eyescandataerror_out : out STD_LOGIC;
    gt1_eyescantrigger_in : in STD_LOGIC;
    gt1_rxbyteisaligned_out : out STD_LOGIC;
    gt1_rxcommadet_out : out STD_LOGIC;
    gt1_rxprbserr_out : out STD_LOGIC;
    gt1_rxprbssel_in : in STD_LOGIC_VECTOR ( 2 downto 0 );
    gt1_rxprbscntreset_in : in STD_LOGIC;
    gt1_rxpcsreset_in : in STD_LOGIC;
    gt1_rxpmareset_in : in STD_LOGIC;
    gt1_rxpmaresetdone_out : out STD_LOGIC;
    gt1_dmonitorout_out : out STD_LOGIC_VECTOR ( 14 downto 0 );
    gt1_rxbufreset_in : in STD_LOGIC;
    gt1_rx_disp_err_out : out STD_LOGIC_VECTOR ( 1 downto 0 );
    gt1_rx_not_in_table_out : out STD_LOGIC_VECTOR ( 1 downto 0 );
    gt1_rx_realign_out : out STD_LOGIC;
    gt1_rx_buf_err_out : out STD_LOGIC;
    gt1_rxresetdone_out : out STD_LOGIC;
    gt1_rxbufstatus_out : out STD_LOGIC_VECTOR ( 2 downto 0 );
    gt2_cplllock_out : out STD_LOGIC;
    gt2_rxlpmen_in : in STD_LOGIC;
    gt2_rxcdrovrden_in : in STD_LOGIC;
    gt2_rxdfelpmreset_in : in STD_LOGIC;
    gt2_rxmonitorout_out : out STD_LOGIC_VECTOR ( 6 downto 0 );
    gt2_rxmonitorsel_in : in STD_LOGIC_VECTOR ( 1 downto 0 );
    gt2_rxcdrhold_in : in STD_LOGIC;
    gt2_eyescanreset_in : in STD_LOGIC;
    gt2_eyescandataerror_out : out STD_LOGIC;
    gt2_eyescantrigger_in : in STD_LOGIC;
    gt2_rxbyteisaligned_out : out STD_LOGIC;
    gt2_rxcommadet_out : out STD_LOGIC;
    gt2_rxprbserr_out : out STD_LOGIC;
    gt2_rxprbssel_in : in STD_LOGIC_VECTOR ( 2 downto 0 );
    gt2_rxprbscntreset_in : in STD_LOGIC;
    gt2_rxpcsreset_in : in STD_LOGIC;
    gt2_rxpmareset_in : in STD_LOGIC;
    gt2_rxpmaresetdone_out : out STD_LOGIC;
    gt2_dmonitorout_out : out STD_LOGIC_VECTOR ( 14 downto 0 );
    gt2_rxbufreset_in : in STD_LOGIC;
    gt2_rx_disp_err_out : out STD_LOGIC_VECTOR ( 1 downto 0 );
    gt2_rx_not_in_table_out : out STD_LOGIC_VECTOR ( 1 downto 0 );
    gt2_rx_realign_out : out STD_LOGIC;
    gt2_rx_buf_err_out : out STD_LOGIC;
    gt2_rxresetdone_out : out STD_LOGIC;
    gt2_rxbufstatus_out : out STD_LOGIC_VECTOR ( 2 downto 0 );
    gt3_cplllock_out : out STD_LOGIC;
    gt3_rxlpmen_in : in STD_LOGIC;
    gt3_rxcdrovrden_in : in STD_LOGIC;
    gt3_rxdfelpmreset_in : in STD_LOGIC;
    gt3_rxmonitorout_out : out STD_LOGIC_VECTOR ( 6 downto 0 );
    gt3_rxmonitorsel_in : in STD_LOGIC_VECTOR ( 1 downto 0 );
    gt3_rxcdrhold_in : in STD_LOGIC;
    gt3_eyescanreset_in : in STD_LOGIC;
    gt3_eyescandataerror_out : out STD_LOGIC;
    gt3_eyescantrigger_in : in STD_LOGIC;
    gt3_rxbyteisaligned_out : out STD_LOGIC;
    gt3_rxcommadet_out : out STD_LOGIC;
    gt3_rxprbserr_out : out STD_LOGIC;
    gt3_rxprbssel_in : in STD_LOGIC_VECTOR ( 2 downto 0 );
    gt3_rxprbscntreset_in : in STD_LOGIC;
    gt3_rxpcsreset_in : in STD_LOGIC;
    gt3_rxpmareset_in : in STD_LOGIC;
    gt3_rxpmaresetdone_out : out STD_LOGIC;
    gt3_dmonitorout_out : out STD_LOGIC_VECTOR ( 14 downto 0 );
    gt3_rxbufreset_in : in STD_LOGIC;
    gt3_rx_disp_err_out : out STD_LOGIC_VECTOR ( 1 downto 0 );
    gt3_rx_not_in_table_out : out STD_LOGIC_VECTOR ( 1 downto 0 );
    gt3_rx_realign_out : out STD_LOGIC;
    gt3_rx_buf_err_out : out STD_LOGIC;
    gt3_rxresetdone_out : out STD_LOGIC;
    gt3_rxbufstatus_out : out STD_LOGIC_VECTOR ( 2 downto 0 );
    gt0_qplllock_in : in STD_LOGIC;
    gt0_qpllrefclklost_in : in STD_LOGIC;
    gt0_qpllreset_out : out STD_LOGIC;
    gt1_qplllock_in : in STD_LOGIC;
    gt1_qpllrefclklost_in : in STD_LOGIC;
    gt1_qpllreset_out : out STD_LOGIC;
    gt_qpllclk_quad2_in : in STD_LOGIC;
    gt_qpllrefclk_quad2_in : in STD_LOGIC;
    gt_qpllclk_quad3_in : in STD_LOGIC;
    gt_qpllrefclk_quad3_in : in STD_LOGIC;
    tx_out_clk : out STD_LOGIC;
    pll_not_locked : in STD_LOGIC
  );

end aurora_rx_4l_64b;

architecture stub of aurora_rx_4l_64b is
attribute syn_black_box : boolean;
attribute black_box_pad_pin : string;
attribute syn_black_box of stub : architecture is true;
attribute black_box_pad_pin of stub : architecture is "m_axi_rx_tdata[63:0],m_axi_rx_tvalid,m_axi_rx_tkeep[7:0],m_axi_rx_tlast,m_axi_ufc_rx_tdata[63:0],m_axi_ufc_rx_tkeep[7:0],m_axi_ufc_rx_tvalid,m_axi_ufc_rx_tlast,rxp[0:3],rxn[0:3],gt_refclk1,frame_err,rx_hard_err,soft_err,rx_lane_up[0:3],rx_channel_up,user_clk,sync_clk,rx_system_reset,power_down,loopback[2:0],gt_reset,tx_lock,sys_reset_out,init_clk_in,rx_resetdone_out,link_reset_out,drpclk_in,drpaddr_in[8:0],drpdi_in[15:0],drpdo_out[15:0],drpen_in,drprdy_out,drpwe_in,drpaddr_in_lane1[8:0],drpdi_in_lane1[15:0],drpdo_out_lane1[15:0],drpen_in_lane1,drprdy_out_lane1,drpwe_in_lane1,drpaddr_in_lane2[8:0],drpdi_in_lane2[15:0],drpdo_out_lane2[15:0],drpen_in_lane2,drprdy_out_lane2,drpwe_in_lane2,drpaddr_in_lane3[8:0],drpdi_in_lane3[15:0],drpdo_out_lane3[15:0],drpen_in_lane3,drprdy_out_lane3,drpwe_in_lane3,gt0_cplllock_out,gt0_rxlpmen_in,gt0_rxcdrovrden_in,gt0_rxdfelpmreset_in,gt0_rxmonitorout_out[6:0],gt0_rxmonitorsel_in[1:0],gt0_rxcdrhold_in,gt0_eyescanreset_in,gt0_eyescandataerror_out,gt0_eyescantrigger_in,gt0_rxbyteisaligned_out,gt0_rxcommadet_out,gt0_rxprbserr_out,gt0_rxprbssel_in[2:0],gt0_rxprbscntreset_in,gt0_rxpcsreset_in,gt0_rxpmareset_in,gt0_rxpmaresetdone_out,gt0_dmonitorout_out[14:0],gt0_rxbufreset_in,gt0_rx_disp_err_out[1:0],gt0_rx_not_in_table_out[1:0],gt0_rx_realign_out,gt0_rx_buf_err_out,gt0_rxresetdone_out,gt0_rxbufstatus_out[2:0],gt1_cplllock_out,gt1_rxlpmen_in,gt1_rxcdrovrden_in,gt1_rxdfelpmreset_in,gt1_rxmonitorout_out[6:0],gt1_rxmonitorsel_in[1:0],gt1_rxcdrhold_in,gt1_eyescanreset_in,gt1_eyescandataerror_out,gt1_eyescantrigger_in,gt1_rxbyteisaligned_out,gt1_rxcommadet_out,gt1_rxprbserr_out,gt1_rxprbssel_in[2:0],gt1_rxprbscntreset_in,gt1_rxpcsreset_in,gt1_rxpmareset_in,gt1_rxpmaresetdone_out,gt1_dmonitorout_out[14:0],gt1_rxbufreset_in,gt1_rx_disp_err_out[1:0],gt1_rx_not_in_table_out[1:0],gt1_rx_realign_out,gt1_rx_buf_err_out,gt1_rxresetdone_out,gt1_rxbufstatus_out[2:0],gt2_cplllock_out,gt2_rxlpmen_in,gt2_rxcdrovrden_in,gt2_rxdfelpmreset_in,gt2_rxmonitorout_out[6:0],gt2_rxmonitorsel_in[1:0],gt2_rxcdrhold_in,gt2_eyescanreset_in,gt2_eyescandataerror_out,gt2_eyescantrigger_in,gt2_rxbyteisaligned_out,gt2_rxcommadet_out,gt2_rxprbserr_out,gt2_rxprbssel_in[2:0],gt2_rxprbscntreset_in,gt2_rxpcsreset_in,gt2_rxpmareset_in,gt2_rxpmaresetdone_out,gt2_dmonitorout_out[14:0],gt2_rxbufreset_in,gt2_rx_disp_err_out[1:0],gt2_rx_not_in_table_out[1:0],gt2_rx_realign_out,gt2_rx_buf_err_out,gt2_rxresetdone_out,gt2_rxbufstatus_out[2:0],gt3_cplllock_out,gt3_rxlpmen_in,gt3_rxcdrovrden_in,gt3_rxdfelpmreset_in,gt3_rxmonitorout_out[6:0],gt3_rxmonitorsel_in[1:0],gt3_rxcdrhold_in,gt3_eyescanreset_in,gt3_eyescandataerror_out,gt3_eyescantrigger_in,gt3_rxbyteisaligned_out,gt3_rxcommadet_out,gt3_rxprbserr_out,gt3_rxprbssel_in[2:0],gt3_rxprbscntreset_in,gt3_rxpcsreset_in,gt3_rxpmareset_in,gt3_rxpmaresetdone_out,gt3_dmonitorout_out[14:0],gt3_rxbufreset_in,gt3_rx_disp_err_out[1:0],gt3_rx_not_in_table_out[1:0],gt3_rx_realign_out,gt3_rx_buf_err_out,gt3_rxresetdone_out,gt3_rxbufstatus_out[2:0],gt0_qplllock_in,gt0_qpllrefclklost_in,gt0_qpllreset_out,gt1_qplllock_in,gt1_qpllrefclklost_in,gt1_qpllreset_out,gt_qpllclk_quad2_in,gt_qpllrefclk_quad2_in,gt_qpllclk_quad3_in,gt_qpllrefclk_quad3_in,tx_out_clk,pll_not_locked";
begin
end;
